You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ja...@apache.org on 2013/02/03 14:24:38 UTC

svn commit: r1441909 [33/45] - in /openoffice/branches/l10n: ./ ext_libraries/apr-util/ ext_libraries/apr/ ext_libraries/hunspell/ ext_sources/ extras/l10n/source/ast/ extras/l10n/source/da/ extras/l10n/source/eu/ extras/l10n/source/gd/ extras/l10n/sou...

Modified: openoffice/branches/l10n/main/svx/inc/galtheme.hrc
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/galtheme.hrc?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/galtheme.hrc (original)
+++ openoffice/branches/l10n/main/svx/inc/galtheme.hrc Sun Feb  3 13:23:59 2013
@@ -25,6 +25,12 @@
 
 #define RID_GALLERYSTR_THEME_START          (6000)
 
+// These defines are used to map gallery names to translated string ressources. Since
+// galleries may be copied from older offices to newer, do *never* change this
+// IDs except adding new ones (and adapting RID_GALLERYSTR_THEME_LAST). The ID
+// *is* written into the binary file *.thm (which is a galler theme combined of
+// three files, *.thm, *.sdv and *.sdg)
+
 #define RID_GALLERYSTR_THEME_3D				(RID_GALLERYSTR_THEME_START + 1)
 #define RID_GALLERYSTR_THEME_ANIMATIONS                 (RID_GALLERYSTR_THEME_START + 2)
 #define RID_GALLERYSTR_THEME_BULLETS                    (RID_GALLERYSTR_THEME_START + 3)
@@ -39,7 +45,7 @@
 #define RID_GALLERYSTR_THEME_MAPS			(RID_GALLERYSTR_THEME_START + 12)
 #define RID_GALLERYSTR_THEME_PEOPLE                     (RID_GALLERYSTR_THEME_START + 13)
 #define RID_GALLERYSTR_THEME_SURFACES                   (RID_GALLERYSTR_THEME_START + 14)
-// free
+#define RID_GALLERYSTR_THEME_HTMLBUTTONS                (RID_GALLERYSTR_THEME_START + 15)
 #define RID_GALLERYSTR_THEME_POWERPOINT                 (RID_GALLERYSTR_THEME_START + 16)
 #define RID_GALLERYSTR_THEME_RULERS			(RID_GALLERYSTR_THEME_START + 17)
 #define RID_GALLERYSTR_THEME_SOUNDS			(RID_GALLERYSTR_THEME_START + 18)
@@ -67,7 +73,14 @@
 #define RID_GALLERYSTR_THEME_FONTWORK					(RID_GALLERYSTR_THEME_START + 37)
 #define RID_GALLERYSTR_THEME_FONTWORK_VERTICAL			(RID_GALLERYSTR_THEME_START + 38)
 
+#define RID_GALLERYSTR_THEME_COMPUTERS                  (RID_GALLERYSTR_THEME_START + 39)
+#define RID_GALLERYSTR_THEME_DIAGRAMS                   (RID_GALLERYSTR_THEME_START + 40)
+#define RID_GALLERYSTR_THEME_ENVIRONMENT                (RID_GALLERYSTR_THEME_START + 41)
+#define RID_GALLERYSTR_THEME_FINANCE                    (RID_GALLERYSTR_THEME_START + 42)
+#define RID_GALLERYSTR_THEME_TRANSPORT                  (RID_GALLERYSTR_THEME_START + 43)
+#define RID_GALLERYSTR_THEME_TXTSHAPES                  (RID_GALLERYSTR_THEME_START + 44)
+
 #define RID_GALLERYSTR_THEME_FIRST			RID_GALLERYSTR_THEME_3D
-#define RID_GALLERYSTR_THEME_LAST			RID_GALLERYSTR_THEME_FONTWORK_VERTICAL
+#define RID_GALLERYSTR_THEME_LAST			RID_GALLERYSTR_THEME_TXTSHAPES
 
 #endif

Modified: openoffice/branches/l10n/main/svx/inc/svx/fontworkgallery.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/fontworkgallery.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/fontworkgallery.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/fontworkgallery.hxx Sun Feb  3 13:23:59 2013
@@ -107,12 +107,12 @@ class SVX_DLLPUBLIC FontWorkGalleryDialo
 	SdrObject**			mppSdrObject;
 	SdrModel*			mpDestModel;
 
-	void			initfavorites(sal_uInt16 nThemeId, std::vector< Bitmap * >& rFavorites);
+	void			initFavorites(sal_uInt16 nThemeId);
 	void			insertSelectedFontwork();
 	void			changeText( SdrTextObj* pObj );
-	void			fillFavorites( sal_uInt16 nThemeId, std::vector< Bitmap * >& rFavorites );
+	void			fillFavorites(sal_uInt16 nThemeId);
 
-	std::vector< Bitmap * > maFavoritesHorizontal;
+	std::vector< BitmapEx> maFavoritesHorizontal;
 
 public:
 	FontWorkGalleryDialog( SdrView* pView, Window* pParent, sal_uInt16 nSID );

Modified: openoffice/branches/l10n/main/svx/inc/svx/gallery.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/gallery.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/gallery.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/gallery.hxx Sun Feb  3 13:23:59 2013
@@ -59,7 +59,7 @@
 #define GALLERY_THEME_MAPS              12
 #define GALLERY_THEME_PEOPLE            13
 #define GALLERY_THEME_SURFACES		14
-// free
+#define GALLERY_THEME_HTMLBUTTONS   15
 #define GALLERY_THEME_POWERPOINT	16
 #define GALLERY_THEME_RULERS		17
 #define GALLERY_THEME_SOUNDS		18
@@ -96,7 +96,7 @@ class FmFormModel;
 class SdrModel;
 class Graphic;
 class FmFormModel;
-class Bitmap;
+class BitmapEx;
 class OutputDevice;
 
 class SVX_DLLPUBLIC GalleryExplorer
@@ -138,10 +138,10 @@ public:
 	static sal_uIntPtr				GetObjCount( sal_uIntPtr nThemeId );
 
 	static sal_Bool					GetGraphicObj( const String& rThemeName, sal_uIntPtr nPos,
-											   Graphic* pGraphic = NULL, Bitmap* pThumb = NULL,
+											   Graphic* pGraphic = NULL, BitmapEx* pThumb = NULL,
 											   sal_Bool bProgess = sal_False );
 	static sal_Bool					GetGraphicObj( sal_uIntPtr nThemeId, sal_uIntPtr nPos,
-											   Graphic* pGraphic = NULL, Bitmap* pThumb = NULL,
+											   Graphic* pGraphic = NULL, BitmapEx* pThumb = NULL,
 											   sal_Bool bProgess = sal_False );
 
 	static sal_Bool					InsertGraphicObj( const String& rThemeName, const Graphic& rGraphic );
@@ -151,9 +151,9 @@ public:
 	static sal_uIntPtr				GetSdrObjCount( sal_uIntPtr nThemeId );
 
 	static sal_Bool					GetSdrObj( const String& rThemeName, sal_uIntPtr nSdrModelPos,
-										   SdrModel* pModel = NULL, Bitmap* pThumb = NULL );
+										   SdrModel* pModel = NULL, BitmapEx* pThumb = NULL );
 	static sal_Bool					GetSdrObj( sal_uIntPtr nThemeId, sal_uIntPtr nSdrModelPos,
-										   SdrModel* pModel = NULL, Bitmap* pThumb = NULL );
+										   SdrModel* pModel = NULL, BitmapEx* pThumb = NULL );
 
 	static sal_Bool					InsertSdrObj( const String& rThemeName, FmFormModel& rModel );
 	static sal_Bool					InsertSdrObj( sal_uIntPtr nThemeId, FmFormModel& rModel );
@@ -163,8 +163,6 @@ public:
 
 	static sal_Bool					EndLocking( const String& rThemeName );
 	static sal_Bool					EndLocking( sal_uIntPtr nThemeId );
-
-    static sal_Bool					DrawCentered( OutputDevice* pOut, const FmFormModel& rModel );
 };
 
 #endif // _GALLERY_HXX_

Modified: openoffice/branches/l10n/main/svx/inc/svx/galtheme.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/galtheme.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/galtheme.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/galtheme.hxx Sun Feb  3 13:23:59 2013
@@ -194,7 +194,7 @@ public:
 									return ImplGetGalleryObject( nPos )->aURL;
 								}
 
-	sal_Bool						GetThumb( sal_uIntPtr nPos, Bitmap& rBmp, sal_Bool bProgress = sal_False );
+	sal_Bool						GetThumb( sal_uIntPtr nPos, BitmapEx& rBmp, sal_Bool bProgress = sal_False );
 
 	SVX_DLLPUBLIC sal_Bool						GetGraphic( sal_uIntPtr nPos, Graphic& rGraphic, sal_Bool bProgress = sal_False );
 	SVX_DLLPUBLIC sal_Bool						InsertGraphic( const Graphic& rGraphic, sal_uIntPtr nInsertPos = LIST_APPEND );

Modified: openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayanimatedbitmapex.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayanimatedbitmapex.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayanimatedbitmapex.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayanimatedbitmapex.hxx Sun Feb  3 13:23:59 2013
@@ -49,16 +49,13 @@ namespace sdr
 			// #i53216# added CursorBlinkTime (in ms)
 			sal_uInt32								mnBlinkTime;
 
-			// bitfield
-			// Flag to remember which state to draw. Inited with sal_False (0)
-			unsigned								mbOverlayState : 1;
+			/// bitfield
+			// Flag to remember which state to draw. Inited with false (0)
+			bool                                    mbOverlayState : 1;
 
 			// geometry creation for OverlayObject
 			virtual drawinglayer::primitive2d::Primitive2DSequence createOverlayObjectPrimitive2DSequence();
 
-            // #i53216# check blink time value range (currently 25 < mnBlinkTime < 10000)
-			void impCheckBlinkTimeValueRange();
-
 		public:
 			OverlayAnimatedBitmapEx(
 				const basegfx::B2DPoint& rBasePos,

Modified: openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayobject.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayobject.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayobject.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlayobject.hxx Sun Feb  3 13:23:59 2013
@@ -85,6 +85,9 @@ namespace sdr
             // a missing implementation
 			virtual drawinglayer::primitive2d::Primitive2DSequence createOverlayObjectPrimitive2DSequence();
 
+            // #i53216# check blink time value range (currently 25 < mnBlinkTime < 10000)
+            sal_uInt32 impCheckBlinkTimeValueRange(sal_uInt32 nBlinkTime) const;
+
 			// region in logical coordinates
 			basegfx::B2DRange								maBaseRange;
 

Modified: openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaypolypolygon.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaypolypolygon.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaypolypolygon.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaypolypolygon.hxx Sun Feb  3 13:23:59 2013
@@ -26,6 +26,7 @@
 
 #include <svx/sdr/overlay/overlayobject.hxx>
 #include <basegfx/polygon/b2dpolypolygon.hxx>
+#include <basegfx/polygon/b2dpolygon.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -33,22 +34,23 @@ namespace sdr
 {
 	namespace overlay
 	{
-		class SVX_DLLPUBLIC OverlayPolyPolygonStriped : public OverlayObject
+		class SVX_DLLPUBLIC OverlayPolyPolygonStripedAndFilled : public OverlayObject
 		{
 		protected:
 			// geometry
-			basegfx::B2DPolyPolygon				maPolyPolygon;
+			basegfx::B2DPolyPolygon				maLinePolyPolygon;
 
 			// geometry creation for OverlayObject
 			virtual drawinglayer::primitive2d::Primitive2DSequence createOverlayObjectPrimitive2DSequence();
 
 		public:
-			OverlayPolyPolygonStriped(const basegfx::B2DPolyPolygon& rPolyPolygon);
-			virtual ~OverlayPolyPolygonStriped();
+			OverlayPolyPolygonStripedAndFilled(
+                const basegfx::B2DPolyPolygon& rLinePolyPolygon);
+			virtual ~OverlayPolyPolygonStripedAndFilled();
 
 			// change geometry
-			basegfx::B2DPolyPolygon getPolyPolygon() const { return maPolyPolygon; }
-			void setPolyPolygon(const basegfx::B2DPolyPolygon& rNew);
+			basegfx::B2DPolyPolygon getLinePolyPolygon() const { return maLinePolyPolygon; }
+			void setLinePolyPolygon(const basegfx::B2DPolyPolygon& rNew);
 
 			// react on stripe definition change
 			virtual void stripeDefinitionHasChanged();

Modified: openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaytools.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaytools.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaytools.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/sdr/overlay/overlaytools.hxx Sun Feb  3 13:23:59 2013
@@ -122,16 +122,15 @@ namespace drawinglayer
 {
 	namespace primitive2d
 	{
-		class OverlayHatchRectanglePrimitive : public DiscreteMetricDependentPrimitive2D
+		class OverlayRectanglePrimitive : public DiscreteMetricDependentPrimitive2D
 		{
 		private:
             // the logic rectangle definition
             basegfx::B2DRange               maObjectRange;
 
-            // the hatch definition
-			double							mfDiscreteHatchDistance;
-			double							mfHatchRotation;
-			basegfx::BColor					maHatchColor;
+            // the graphic definition
+			basegfx::BColor					maColor;
+            double                          mfTransparence;
 
             // the dscrete grow and shrink of the box
             double							mfDiscreteGrow;
@@ -144,21 +143,19 @@ namespace drawinglayer
 			virtual Primitive2DSequence create2DDecomposition(const geometry::ViewInformation2D& rViewInformation) const;
 
 		public:
-			OverlayHatchRectanglePrimitive(
+			OverlayRectanglePrimitive(
                 const basegfx::B2DRange& rObjectRange,
-				double fDiscreteHatchDistance,
-				double fHatchRotation,
-				const basegfx::BColor& rHatchColor,
+				const basegfx::BColor& rColor,
+                double fTransparence,
 				double fDiscreteGrow,
                 double fDiscreteShrink,
                 double fRotation);
 
 			// data access
             const basegfx::B2DRange& getObjectRange() const { return maObjectRange; }
-			double getDiscreteHatchDistance() const { return mfDiscreteHatchDistance; }
-			double getHatchRotation() const { return mfHatchRotation; }
-			const basegfx::BColor& getHatchColor() const { return maHatchColor; }
-			double getDiscreteGrow() const { return mfDiscreteGrow; }
+			const basegfx::BColor& getColor() const { return maColor; }
+            double getTransparence() const { return mfTransparence; }
+            double getDiscreteGrow() const { return mfDiscreteGrow; }
             double getDiscreteShrink() const { return mfDiscreteShrink; }
             double getRotation() const { return mfRotation; }
 

Modified: openoffice/branches/l10n/main/svx/inc/svx/sdr/primitive2d/svx_primitivetypes2d.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/sdr/primitive2d/svx_primitivetypes2d.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/sdr/primitive2d/svx_primitivetypes2d.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/sdr/primitive2d/svx_primitivetypes2d.hxx Sun Feb  3 13:23:59 2013
@@ -46,7 +46,7 @@
 #define PRIMITIVE2D_ID_SDRBORDERLINEPRIMITIVE2D			(PRIMITIVE2D_ID_RANGE_SVX| 15)
 #define PRIMITIVE2D_ID_OVERLAYBITMAPEXPRIMITIVE			(PRIMITIVE2D_ID_RANGE_SVX| 16)
 #define PRIMITIVE2D_ID_OVERLAYCROSSHAIRPRIMITIVE        (PRIMITIVE2D_ID_RANGE_SVX| 17)
-#define PRIMITIVE2D_ID_OVERLAYHATCHRECTANGLEPRIMITIVE   (PRIMITIVE2D_ID_RANGE_SVX| 18)
+#define PRIMITIVE2D_ID_OVERLAYRECTANGLEPRIMITIVE        (PRIMITIVE2D_ID_RANGE_SVX| 18)
 #define PRIMITIVE2D_ID_OVERLAYHELPLINESTRIPEDPRIMITIVE  (PRIMITIVE2D_ID_RANGE_SVX| 19)
 #define PRIMITIVE2D_ID_OVERLAYROLLINGRECTANGLEPRIMITIVE (PRIMITIVE2D_ID_RANGE_SVX| 20)
 #define PRIMITIVE2D_ID_SDRCONTROLPRIMITIVE2D            (PRIMITIVE2D_ID_RANGE_SVX| 21)

Modified: openoffice/branches/l10n/main/svx/inc/svx/svdhdl.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/svdhdl.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/svdhdl.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/svdhdl.hxx Sun Feb  3 13:23:59 2013
@@ -138,7 +138,9 @@ enum BitmapMarkerKind
 	AnchorPressedTR,
 
 	// for SJ and the CustomShapeHandles:
-	Customshape1
+	Customshape_7x7,
+	Customshape_9x9,
+	Customshape_11x11
 };
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////

Modified: openoffice/branches/l10n/main/svx/inc/svx/svdmodel.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/svdmodel.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/svdmodel.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/svdmodel.hxx Sun Feb  3 13:23:59 2013
@@ -742,8 +742,6 @@ public:
 		This returns false if undo was disabled using EnableUndo( false ) and
 		also during the runtime of the Undo() and Redo() methods. */
 	bool IsUndoEnabled() const;
-
-	void SetDrawingLayerPoolDefaults();
 };
 
 typedef tools::WeakReference< SdrModel > SdrModelWeakRef;

Modified: openoffice/branches/l10n/main/svx/inc/svx/svdview.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/svdview.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/svdview.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/svdview.hxx Sun Feb  3 13:23:59 2013
@@ -32,6 +32,8 @@
 #include "svx/svxdllapi.h"
 #include <svx/svdcrtv.hxx>
 #include <unotools/options.hxx>
+#include <basegfx/polygon/b2dpolypolygon.hxx>
+#include <basegfx/polygon/b2dpolygon.hxx>
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 //
@@ -155,7 +157,9 @@ class SVX_DLLPUBLIC SdrDropMarkerOverlay
 	// The OverlayObjects
 	::sdr::overlay::OverlayObjectList				maObjects;
 
-	void ImplCreateOverlays(const SdrView& rView, const basegfx::B2DPolyPolygon& rPolyPolygon);
+	void ImplCreateOverlays(
+        const SdrView& rView, 
+        const basegfx::B2DPolyPolygon& rLinePolyPolygon);
 
 public:
 	SdrDropMarkerOverlay(const SdrView& rView, const SdrObject& rObject);

Modified: openoffice/branches/l10n/main/svx/inc/svx/svdxcgv.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/svdxcgv.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/svdxcgv.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/svdxcgv.hxx Sun Feb  3 13:23:59 2013
@@ -65,6 +65,7 @@ protected:
 
 public:
 	// Alle markierten Objekte auf dem angegebenen OutputDevice ausgeben.
+    ::std::vector< SdrObject* > GetMarkedObjects() const;
 	virtual void        DrawMarkedObj(OutputDevice& rOut) const;
 
 	// Z.B. fuer's Clipboard, Drag&Drop, ...

Modified: openoffice/branches/l10n/main/svx/inc/svx/xoutbmp.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/inc/svx/xoutbmp.hxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/inc/svx/xoutbmp.hxx (original)
+++ openoffice/branches/l10n/main/svx/inc/svx/xoutbmp.hxx Sun Feb  3 13:23:59 2013
@@ -61,19 +61,11 @@ public:
 
 	static GraphicFilter* pGrfFilter;
 
-	static BitmapEx		CreateQuickDrawBitmapEx( const Graphic& rGraphic, const OutputDevice& rCompDev,
-												 const MapMode& rMapMode, const Size& rLogSize,
-												 const Point& rPoint, const Size& rSize );
 	static Graphic		MirrorGraphic( const Graphic& rGraphic, const sal_uIntPtr nMirrorFlags );
 	static Animation	MirrorAnimation( const Animation& rAnimation, sal_Bool bHMirr, sal_Bool bVMirr );
 	static sal_uInt16		WriteGraphic( const Graphic& rGraphic, String& rFileName,
 									  const String& rFilterName, const sal_uIntPtr nFlags = 0L,
 									  const Size* pMtfSize_100TH_MM = NULL );
-	static void			DrawQuickDrawBitmapEx( OutputDevice* pOutDev, const Point& rPt,
-											   const Size& rSize, const BitmapEx& rBmpEx );
-	static void			DrawTiledBitmapEx( OutputDevice* pOutDev, const Point& rStartPt, const Size& rGrfSize,
-										   const Rectangle& rTileRect, const BitmapEx& rBmpEx );
-
 	static sal_uInt16		ExportGraphic( const Graphic& rGraphic, const INetURLObject& rURL,
 									   GraphicFilter& rFilter, const sal_uInt16 nFormat,
 									   const com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >* pFilterData = NULL );

Modified: openoffice/branches/l10n/main/svx/source/customshapes/EnhancedCustomShape2d.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/customshapes/EnhancedCustomShape2d.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/customshapes/EnhancedCustomShape2d.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/customshapes/EnhancedCustomShape2d.cxx Sun Feb  3 13:23:59 2013
@@ -1495,6 +1495,36 @@ void EnhancedCustomShape2d::CreateSubPat
 				}
 				break;
 
+                case QUADRATICCURVETO :
+                {
+                    for ( sal_uInt16 i = 0; ( i < nPntCount ) && ( ( rSrcPt + 1 ) < nCoordSize ); i++ )
+                    {
+                        if ( rSrcPt )
+                        {
+                            const Point aPreviousEndPoint(GetPoint( seqCoordinates[ rSrcPt - 1 ], sal_True, sal_True));
+                            const Point aControlQ(GetPoint( seqCoordinates[ rSrcPt++ ], sal_True, sal_True ));
+                            const Point aEnd(GetPoint( seqCoordinates[ rSrcPt++ ], sal_True, sal_True ));
+                            const Point aControlA((aPreviousEndPoint + (aControlQ * 2)) / 3);
+                            const Point aControlB(((aControlQ * 2) + aEnd) / 3);
+
+                            DBG_ASSERT(aNewB2DPolygon.count(), "EnhancedCustomShape2d::CreateSubPath: Error in adding Q control point (!)");
+                            aNewB2DPolygon.appendBezierSegment(
+                                basegfx::B2DPoint(aControlA.X(), aControlA.Y()),
+                                basegfx::B2DPoint(aControlB.X(), aControlB.Y()),
+                                basegfx::B2DPoint(aEnd.X(), aEnd.Y()));
+                        }
+                        else // no previous point , do a moveto
+                        {
+                            rSrcPt++; // skip control point
+                            const Point aEnd(GetPoint( seqCoordinates[ rSrcPt++ ], sal_True, sal_True ));
+
+                            DBG_ASSERT(aNewB2DPolygon.count(), "EnhancedCustomShape2d::CreateSubPath: Error in adding Q control point (!)");
+                            aNewB2DPolygon.append(basegfx::B2DPoint(aEnd.X(), aEnd.Y()));
+                        }
+                    }
+                }
+                break;
+
 				case ANGLEELLIPSE :
 				{
 					if ( nPntCount )

Modified: openoffice/branches/l10n/main/svx/source/dialog/docrecovery.src
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/dialog/docrecovery.src?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/dialog/docrecovery.src (original)
+++ openoffice/branches/l10n/main/svx/source/dialog/docrecovery.src Sun Feb  3 13:23:59 2013
@@ -371,7 +371,7 @@ TabPage RID_SVXPAGE_ERR_REP_WELCOME
 		Pos = MAP_APPFONT( RECOV_COL1, RECOV_ROW2 );
 		Size = MAP_APPFONT( RECOV_CONTROLWIDTH, (RECOV_ROW7-RECOV_ROW2-RSC_SP_CTRL_Y) );
 		WordBreak = TRUE;
-		Text[ en-US ] = "This error report tool gathers information about how %PRODUCTNAME is working and sends it to Oracle to help improve future versions.\n\nIt's easy - just send the report without any further effort on your part by clicking 'Send' in the next dialog, or you can briefly describe how the error occurred and then click 'Send'. If you want to see the report, click the 'Show Report' button. No data will be sent if you click 'Do Not Send'.\n\nCustomer Privacy\nThe information gathered is limited to data concerning the state of %PRODUCTNAME %PRODUCTVERSION when the error occurred. Other information about passwords or document contents is not collected.\n\nThe information will only be used to improve the quality of %PRODUCTNAME and will not be shared with third parties.\nFor more information on Oracle's privacy policy, visit\nwww.oracle.com/html/services-privacy-policy.html";
+		Text[ en-US ] = "This error report tool gathers information about how %PRODUCTNAME is working and sends it to Apache OpenOffice to help improve future versions.\n\nIt's easy - just send the report without any further effort on your part by clicking 'Send' in the next dialog, or you can briefly describe how the error occurred and then click 'Send'. If you want to see the report, click the 'Show Report' button. No data will be sent if you click 'Do Not Send'.\n\nCustomer Privacy\nThe information gathered is limited to data concerning the state of %PRODUCTNAME %PRODUCTVERSION when the error occurred. Other information about passwords or document contents is not collected.\n\nThe information will only be used to improve the quality of %PRODUCTNAME and will not be shared with third parties.\nFor more information on Apache OpenOffice's privacy policy, visit\nwww.oracle.com/html/services-privacy-policy.html";
 	};
 	FixedLine FL_RECOV_BOTTOM
 	{
@@ -479,7 +479,7 @@ TabPage RID_SVXPAGE_ERR_REP_SEND
         Pos = MAP_APPFONT( ERRSEND_COL0, ERRSEND_ROW12 );
         Size = MAP_APPFONT( ERRSEND_CONTROLWIDTH2, RSC_CD_CHECKBOX_HEIGHT );
 		Check = FALSE;
-        Text[ en-US ] = "~I allow Oracle to contact me regarding this report.";
+        Text[ en-US ] = "~I allow Apache OpenOffice to contact me regarding this report.";
 	};
 	FixedText FT_ERRSEND_EMAILADDR
 	{
@@ -647,4 +647,4 @@ ModalDialog RID_SVX_MDLG_ERR_REP_PREVIEW
 		Size = MAP_APPFONT( RSC_CD_PUSHBUTTON_WIDTH, RSC_CD_PUSHBUTTON_HEIGHT );
         DefButton = TRUE;
 	};
-};
\ No newline at end of file
+};

Modified: openoffice/branches/l10n/main/svx/source/dialog/sendreportw32.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/dialog/sendreportw32.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/dialog/sendreportw32.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/dialog/sendreportw32.cxx Sun Feb  3 13:23:59 2013
@@ -93,7 +93,7 @@ namespace svx{
 
 			if ( ERROR_SUCCESS == RegReadValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("HTTPProxyServer"),
 				szBuffer,
 				sizeof(szBuffer) ) )
@@ -102,7 +102,7 @@ namespace svx{
 			DWORD	dwProxyPort;
 			if ( ERROR_SUCCESS == RegReadValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("HTTPProxyPort"),
 				&dwProxyPort,
 				sizeof(dwProxyPort) ) )
@@ -113,7 +113,7 @@ namespace svx{
 
 			if ( ERROR_SUCCESS == RegReadValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("ReturnAddress"),
 				szBuffer,
 				sizeof(szBuffer) ) )
@@ -122,7 +122,7 @@ namespace svx{
 			DWORD	fAllowContact = sal_False;
 			RegReadValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("AllowContact"),
 				&fAllowContact,
 				sizeof(fAllowContact) );
@@ -131,7 +131,7 @@ namespace svx{
 			DWORD	uInternetConnection = 0;
 			RegReadValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("HTTPConnection"),
 				&uInternetConnection,
 				sizeof(uInternetConnection) );
@@ -145,7 +145,7 @@ namespace svx{
 			const _TCHAR	*lpHTTPProxyServer = reinterpret_cast<LPCTSTR>(maParams.maHTTPProxyServer.GetBuffer());
 			RegWriteValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("HTTPProxyServer"), REG_SZ,
 				lpHTTPProxyServer,
 				sizeof(TCHAR) * (_tcslen(lpHTTPProxyServer) + 1) );
@@ -155,7 +155,7 @@ namespace svx{
 
 			RegWriteValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("HTTPProxyPort"), REG_DWORD,
 				&dwProxyPort,
 				sizeof(DWORD) );
@@ -163,7 +163,7 @@ namespace svx{
 			DWORD	fAllowContact = IsContactAllowed();
 			RegWriteValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("AllowContact"), REG_DWORD,
 				&fAllowContact,
 				sizeof(DWORD) );
@@ -173,7 +173,7 @@ namespace svx{
 
 			RegWriteValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("HTTPConnection"), REG_DWORD,
 				&uInternetConnection,
 				sizeof(DWORD) );
@@ -181,7 +181,7 @@ namespace svx{
 			const _TCHAR	*lpEmail = reinterpret_cast<LPCTSTR>(GetEMailAddress().GetBuffer());
 			RegWriteValue(
 				HKEY_CURRENT_USER,
-				TEXT("SOFTWARE\\OpenOffice.org\\CrashReport"),
+				TEXT("SOFTWARE\\Apache OpenOffice\\CrashReport"),
 				TEXT("ReturnAddress"), REG_SZ,
 				lpEmail,
 				sizeof(TCHAR) * (_tcslen(lpEmail) + 1) );

Modified: openoffice/branches/l10n/main/svx/source/engine3d/dragmt3d.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/engine3d/dragmt3d.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/engine3d/dragmt3d.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/engine3d/dragmt3d.cxx Sun Feb  3 13:23:59 2013
@@ -300,7 +300,8 @@ void E3dDragMethod::CreateOverlayGeometr
 
 	if(aResult.count())
 	{
-		::sdr::overlay::OverlayPolyPolygonStriped* pNew = new ::sdr::overlay::OverlayPolyPolygonStriped(aResult);
+		::sdr::overlay::OverlayPolyPolygonStripedAndFilled* pNew = new ::sdr::overlay::OverlayPolyPolygonStripedAndFilled(
+            aResult);
 		rOverlayManager.add(*pNew);
 		addToOverlayObjectList(*pNew);
 	}

Modified: openoffice/branches/l10n/main/svx/source/engine3d/view3d.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/engine3d/view3d.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/engine3d/view3d.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/engine3d/view3d.cxx Sun Feb  3 13:23:59 2013
@@ -219,7 +219,8 @@ void Impl3DMirrorConstructOverlay::SetMi
 			        basegfx::B2DPolyPolygon aPolyPolygon(mpPolygons[b]);
 			        aPolyPolygon.transform(aMatrixTransform);
 
-			        ::sdr::overlay::OverlayPolyPolygonStriped* pNew = new ::sdr::overlay::OverlayPolyPolygonStriped(aPolyPolygon);
+			        ::sdr::overlay::OverlayPolyPolygonStripedAndFilled* pNew = new ::sdr::overlay::OverlayPolyPolygonStripedAndFilled(
+                        aPolyPolygon);
 			        pTargetOverlay->add(*pNew);
 			        maObjects.append(*pNew);
                 }

Modified: openoffice/branches/l10n/main/svx/source/form/formcontrolfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/form/formcontrolfactory.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/form/formcontrolfactory.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/form/formcontrolfactory.cxx Sun Feb  3 13:23:59 2013
@@ -464,7 +464,7 @@ namespace svxform
                 {
                     const ::rtl::OUString sScaleModeProperty( RTL_CONSTASCII_USTRINGPARAM( "ScaleMode" ) );
                     if ( xPSI->hasPropertyByName( sScaleModeProperty ) )
-                        _rxControlModel->setPropertyValue( sScaleModeProperty, makeAny( ImageScaleMode::Isotropic ) );
+                        _rxControlModel->setPropertyValue( sScaleModeProperty, makeAny( ImageScaleMode::ISOTROPIC ) );
                 }
                 break;
             }

Modified: openoffice/branches/l10n/main/svx/source/gallery2/galctrl.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/gallery2/galctrl.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/gallery2/galctrl.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/gallery2/galctrl.cxx Sun Feb  3 13:23:59 2013
@@ -300,6 +300,16 @@ void GalleryPreview::PreviewMedia( const
 
 // ------------------------------------------------------------------------
 
+void drawCheckered(OutputDevice& rOut, const Point& rPos, const Size& rSize)
+{
+    // draw checkered background
+    static const sal_uInt32 nLen(8);
+    static const Color aW(COL_WHITE);
+    static const Color aG(0xef, 0xef, 0xef);
+
+    rOut.DrawCheckered(rPos, rSize, nLen, aW, aG);
+}
+
 // -------------------
 // - GalleryIconView -
 // -------------------
@@ -364,21 +374,37 @@ void GalleryIconView::UserDraw( const Us
 			const Rectangle&	rRect = rUDEvt.GetRect();
 			OutputDevice*		pDev = rUDEvt.GetDevice();
 			Graphic 			aGraphic;
+            bool bTransparent(false);
 
 			if( pObj->IsThumbBitmap() )
 			{
-				Bitmap aBmp( pObj->GetThumbBmp() );
+				BitmapEx aBitmapEx;
 
 				if( pObj->GetObjKind() == SGA_OBJ_SOUND )
-					aBmp.Replace( COL_LIGHTMAGENTA, COL_WHITE );
-
-				if( ( pDev->GetBitCount() <= 8 ) && ( aBmp.GetBitCount() >= 8 ) )
-					aBmp.Dither( BMP_DITHER_FLOYD );
+                {
+                    Bitmap aTemp = pObj->GetThumbBmp().GetBitmap();
+                    
+                    aTemp.Replace( COL_LIGHTMAGENTA, COL_WHITE );
+                    aBitmapEx = BitmapEx(aTemp);
+                }
+                else
+                {
+                    aBitmapEx = pObj->GetThumbBmp();
+                    bTransparent = aBitmapEx.IsTransparent();
+                }
+
+				if( ( pDev->GetBitCount() <= 8 ) && ( aBitmapEx.GetBitCount() >= 8 ) )
+                {
+					aBitmapEx.Dither( BMP_DITHER_FLOYD );
+                }
 
-				aGraphic = aBmp;
+				aGraphic = aBitmapEx;
 			}
 			else
+            {
 				aGraphic = pObj->GetThumbMtf();
+                bTransparent = true;
+            }
 
 			Size aSize( aGraphic.GetSizePixel( pDev ) );
 
@@ -406,6 +432,12 @@ void GalleryIconView::UserDraw( const Us
 				const Point aPos( ( ( rRect.GetWidth() - aSize.Width() ) >> 1 ) + rRect.Left(),
 								  ( ( rRect.GetHeight() - aSize.Height() ) >> 1 ) + rRect.Top() );
 
+                if(bTransparent)
+                {
+                    // draw checkered background
+                    drawCheckered(*pDev, aPos, aSize);
+                }
+
 				aGraphic.Draw( pDev, aPos, aSize );
 			}
 
@@ -604,13 +636,24 @@ void GalleryListView::PaintField( Output
             {
                 Rectangle       aOutputRect( rRect.TopLeft(), Size( rRect.GetHeight(), rRect.GetHeight() ) );
     			GraphicObject   aGrfObj;
+                bool bTransparent(false);
 
                 if( pObj->GetObjKind() == SGA_OBJ_SOUND )
+                {
                     aGrfObj = Graphic( BitmapEx( GAL_RESID( RID_SVXBMP_GALLERY_MEDIA ) ) );
+                }
                 else if( pObj->IsThumbBitmap() )
-				    aGrfObj = Graphic( pObj->GetThumbBmp() );
+                {
+                    const BitmapEx aBitmapEx(pObj->GetThumbBmp());
+
+                    bTransparent = aBitmapEx.IsTransparent();
+				    aGrfObj = Graphic(aBitmapEx);
+                }
 			    else
+                {
 				    aGrfObj = Graphic( pObj->GetThumbMtf() );
+                    bTransparent = true;
+                }
 
 			    Size aSize( rDev.LogicToPixel( aGrfObj.GetPrefSize(), aGrfObj.GetPrefMapMode() ) );
 
@@ -641,7 +684,13 @@ void GalleryListView::PaintField( Output
 				    const Point aPos( ( ( aOutputRect.GetWidth() - aSize.Width() ) >> 1 ) + aOutputRect.Left(),
 								      ( ( aOutputRect.GetHeight() - aSize.Height() ) >> 1 ) + aOutputRect.Top() );
 
-				    aGrfObj.Draw( &rDev, aPos, aSize );
+                    if(bTransparent)
+                    {
+                        // draw checkered background
+                        drawCheckered(rDev, aPos, aSize);
+                    }
+
+                    aGrfObj.Draw( &rDev, aPos, aSize );
 			    }
 
 			    rDev.DrawText( Point( aOutputRect.Right() + 6, nTextPosY ), GalleryBrowser2::GetItemText( *mpTheme, *pObj, GALLERY_ITEM_TITLE ) );

Modified: openoffice/branches/l10n/main/svx/source/gallery2/galexpl.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/gallery2/galexpl.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/gallery2/galexpl.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/gallery2/galexpl.cxx Sun Feb  3 13:23:59 2013
@@ -260,7 +260,7 @@ sal_uIntPtr GalleryExplorer::GetObjCount
 // ------------------------------------------------------------------------
 
 sal_Bool GalleryExplorer::GetGraphicObj( const String& rThemeName, sal_uIntPtr nPos,
-									 Graphic* pGraphic, Bitmap* pThumb,
+									 Graphic* pGraphic, BitmapEx* pThumb,
 									 sal_Bool bProgress )
 {
 	Gallery*	pGal = ImplGetGallery();
@@ -289,7 +289,7 @@ sal_Bool GalleryExplorer::GetGraphicObj(
 // ------------------------------------------------------------------------
 
 sal_Bool GalleryExplorer::GetGraphicObj( sal_uIntPtr nThemeId, sal_uIntPtr nPos,
-									 Graphic* pGraphic, Bitmap* pThumb,
+									 Graphic* pGraphic, BitmapEx* pThumb,
 									 sal_Bool bProgress )
 {
 	Gallery* pGal = ImplGetGallery();
@@ -362,7 +362,7 @@ sal_uIntPtr GalleryExplorer::GetSdrObjCo
 // ------------------------------------------------------------------------
 
 sal_Bool GalleryExplorer::GetSdrObj( const String& rThemeName, sal_uIntPtr nSdrModelPos,
-								 SdrModel* pModel, Bitmap* pThumb )
+								 SdrModel* pModel, BitmapEx* pThumb )
 {
 	Gallery*	pGal = ImplGetGallery();
 	sal_Bool		bRet = sal_False;
@@ -399,7 +399,7 @@ sal_Bool GalleryExplorer::GetSdrObj( con
 // ------------------------------------------------------------------------
 
 sal_Bool GalleryExplorer::GetSdrObj( sal_uIntPtr nThemeId, sal_uIntPtr nSdrModelPos,
-								 SdrModel* pModel, Bitmap* pThumb )
+								 SdrModel* pModel, BitmapEx* pThumb )
 {
 	Gallery* pGal = ImplGetGallery();
 	return( pGal ? GetSdrObj( pGal->GetThemeName( nThemeId ), nSdrModelPos, pModel, pThumb ) : sal_False );
@@ -504,8 +504,4 @@ sal_Bool GalleryExplorer::EndLocking( sa
 }
 
 // -----------------------------------------------------------------------------
-
-sal_Bool GalleryExplorer::DrawCentered( OutputDevice* pOut, const FmFormModel& rModel )
-{
-	return SgaObjectSvDraw::DrawCentered( pOut, rModel );
-}
+// eof

Modified: openoffice/branches/l10n/main/svx/source/gallery2/gallery1.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/gallery2/gallery1.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/gallery2/gallery1.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/gallery2/gallery1.cxx Sun Feb  3 13:23:59 2013
@@ -601,7 +601,18 @@ String Gallery::GetThemeName( sal_uIntPt
 			case( GALLERY_THEME_RULERS ): aFallback = "Rulers"; break;
 			case( GALLERY_THEME_SOUNDS ): aFallback = "Sounds"; break;
 
-			default:
+            case( RID_GALLERYSTR_THEME_ARROWS ): aFallback = "Arrows"; break;
+            case( RID_GALLERYSTR_THEME_COMPUTERS ): aFallback = "Computers"; break;
+            case( RID_GALLERYSTR_THEME_DIAGRAMS ): aFallback = "Diagrams"; break;
+            case( RID_GALLERYSTR_THEME_EDUCATION ): aFallback = "Education"; break;
+            case( RID_GALLERYSTR_THEME_ENVIRONMENT ): aFallback = "Environment"; break;
+            case( RID_GALLERYSTR_THEME_FINANCE ): aFallback = "Finance"; break;
+            case( RID_GALLERYSTR_THEME_PEOPLE ): aFallback = "People"; break;
+            case( RID_GALLERYSTR_THEME_SYMBOLS ): aFallback = "Symbols"; break;
+            case( RID_GALLERYSTR_THEME_TRANSPORT ): aFallback = "Transport"; break;
+            case( RID_GALLERYSTR_THEME_TXTSHAPES ): aFallback = "Textshapes"; break;
+
+            default:
 			break;
 		}
 

Modified: openoffice/branches/l10n/main/svx/source/gallery2/galmisc.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/gallery2/galmisc.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/gallery2/galmisc.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/gallery2/galmisc.cxx Sun Feb  3 13:23:59 2013
@@ -606,7 +606,7 @@ sal_Bool GalleryTransferable::GetData( c
 	}
 	else if( ( FORMAT_BITMAP == nFormat ) && mpGraphicObject )
 	{
-		bRet = SetBitmap( mpGraphicObject->GetGraphic().GetBitmap(), rFlavor );
+		bRet = SetBitmapEx( mpGraphicObject->GetGraphic().GetBitmapEx(), rFlavor );
 	}
 
 	return bRet;

Modified: openoffice/branches/l10n/main/svx/source/gallery2/galobj.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/gallery2/galobj.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/gallery2/galobj.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/gallery2/galobj.cxx Sun Feb  3 13:23:59 2013
@@ -29,10 +29,8 @@
 #include <com/sun/star/lang/XUnoTunnel.hpp>
 #include <sfx2/objsh.hxx>
 #include <sfx2/docfac.hxx>
-
 #include <comphelper/classids.hxx>
 #include <unotools/pathoptions.hxx>
-
 #include <tools/rcid.h>
 #include <tools/vcompat.hxx>
 #include <vcl/virdev.hxx>
@@ -45,7 +43,7 @@
 #include "galobj.hxx"
 #include <vcl/salbtype.hxx>		// FRound
 #include <vcl/svapp.hxx>
-
+#include <vcl/dibtools.hxx>
 #include "gallerydrawmodel.hxx"
 
 using namespace ::com::sun::star;
@@ -91,11 +89,12 @@ sal_Bool SgaObject::CreateThumb( const G
 		            else
 		                aBmpSize.Height() = FRound( aBmpSize.Width() / fFactorLog );
 
-		            aBmpEx.SetSizePixel( aBmpSize );
+		            aBmpEx.SetSizePixel( aBmpSize, BMP_SCALE_BESTQUALITY );
 		        }
 		    }
 
-			aThumbBmp = aBmpEx.GetBitmap( &aWhite );
+            // take over BitmapEx
+			aThumbBmp = aBmpEx;
 
 			if( ( aBmpSize.Width() <= S_THUMB ) && ( aBmpSize.Height() <= S_THUMB ) )
 			{
@@ -108,8 +107,10 @@ sal_Bool SgaObject::CreateThumb( const G
 				const Size	aNewSize( Max( (long) (fFactor < 1. ? S_THUMB * fFactor : S_THUMB), 8L ),
 									  Max( (long) (fFactor < 1. ? S_THUMB : S_THUMB / fFactor), 8L ) );
 
-				if( aThumbBmp.Scale( (double) aNewSize.Width() / aBmpSize.Width(),
-									 (double) aNewSize.Height() / aBmpSize.Height(), BMP_SCALE_INTERPOLATE ) )
+				if(aThumbBmp.Scale(
+                    (double) aNewSize.Width() / aBmpSize.Width(),
+                    (double) aNewSize.Height() / aBmpSize.Height(), 
+                    BMP_SCALE_BESTQUALITY ) )
 				{
 					aThumbBmp.Convert( BMP_CONVERSION_8BIT_COLORS );
 					bRet = sal_True;
@@ -127,8 +128,8 @@ sal_Bool SgaObject::CreateThumb( const G
 		else
 			aSize.Height() = (sal_Int32)( S_THUMB / fFactor );
 
-        const GraphicConversionParameters aParameters(aSize);
-        aThumbBmp = rGraphic.GetBitmap(aParameters);
+        const GraphicConversionParameters aParameters(aSize, false, true, true, true);
+        aThumbBmp = rGraphic.GetBitmapEx(aParameters);
 
 		if( !aThumbBmp.IsEmpty() )
 		{
@@ -157,7 +158,7 @@ void SgaObject::WriteData( SvStream& rOu
 		rOut.SetCompressMode( COMPRESSMODE_ZBITMAP );
 		rOut.SetVersion( SOFFICE_FILEFORMAT_50 );
 
-		rOut << aThumbBmp;
+        WriteDIBBitmapEx(aThumbBmp, rOut);
 
 		rOut.SetVersion( nOldVersion );
 		rOut.SetCompressMode( nOldCompressMode );
@@ -181,9 +182,13 @@ void SgaObject::ReadData(SvStream& rIn, 
 	rIn >> nTmp32 >> nTmp16 >> rReadVersion >> nTmp16 >> bIsThumbBmp;
 
 	if( bIsThumbBmp )
-		rIn >> aThumbBmp;
+    {
+        ReadDIBBitmapEx(aThumbBmp, rIn);
+    }
 	else
+    {
 		rIn >> aThumbMtf;
+    }
 
 	rIn >> aTmpStr; aURL = INetURLObject( String( aTmpStr.GetBuffer(), RTL_TEXTENCODING_UTF8 ) );
 }
@@ -352,7 +357,7 @@ SgaObjectSound::~SgaObjectSound()
 
 // ------------------------------------------------------------------------
 
-Bitmap SgaObjectSound::GetThumbBmp() const
+BitmapEx SgaObjectSound::GetThumbBmp() const
 {
 	sal_uInt16 nId;
 
@@ -373,9 +378,8 @@ Bitmap SgaObjectSound::GetThumbBmp() con
 	}
 
 	const BitmapEx  aBmpEx( GAL_RESID( nId ) );
-	const Color     aTransColor( COL_WHITE );
-
-	return aBmpEx.GetBitmap( &aTransColor );
+	
+    return aBmpEx;
 }
 
 // ------------------------------------------------------------------------
@@ -519,24 +523,50 @@ sal_Bool SgaObjectSvDraw::CreateThumb( c
 	sal_Bool		bRet = sal_False;
 
 	if ( CreateIMapGraphic( rModel, aGraphic, aImageMap ) )
+    {
 		bRet = SgaObject::CreateThumb( aGraphic );
+    }
 	else
 	{
-        VirtualDevice aVDev;
-
-        aVDev.SetOutputSizePixel( Size( S_THUMB*2, S_THUMB*2 ) );
+        const FmFormPage* pPage = static_cast< const FmFormPage* >(rModel.GetPage(0));
 
-        bRet = DrawCentered( &aVDev, rModel );
-        if( bRet )
+        if(pPage)
         {
-            aThumbBmp = aVDev.GetBitmap( Point(), aVDev.GetOutputSizePixel() );
+            const Rectangle aObjRect(pPage->GetAllObjBoundRect());
 
-			Size aMS( 2, 2 );
-			BmpFilterParam aParam( aMS );
-			aThumbBmp.Filter( BMP_FILTER_MOSAIC, &aParam );
-			aThumbBmp.Scale( Size( S_THUMB, S_THUMB ) );
+            if(aObjRect.GetWidth() && aObjRect.GetHeight())
+            {
+                VirtualDevice aVDev;
+                FmFormView aView(const_cast< FmFormModel* >(&rModel), &aVDev);
 
-	        aThumbBmp.Convert( BMP_CONVERSION_8BIT_COLORS );
+                aView.ShowSdrPage(const_cast< FmFormPage* >(pPage));
+                aView.MarkAllObj();
+                aThumbBmp = aView.GetMarkedObjBitmapEx();
+
+                const Size aDiscreteSize(aThumbBmp.GetSizePixel());
+
+                if(aDiscreteSize.Width() && aDiscreteSize.Height())
+                {
+                    sal_uInt32 nTargetSizeX(S_THUMB);
+                    sal_uInt32 nTargetSizeY(S_THUMB);
+
+                    if(aDiscreteSize.Width() > aDiscreteSize.Height())
+                    {
+                        nTargetSizeY = (aDiscreteSize.Height() * nTargetSizeX) / aDiscreteSize.Width();
+                    }
+                    else
+                    {
+                        nTargetSizeX = (aDiscreteSize.Width() * nTargetSizeY) / aDiscreteSize.Height();
+                    }
+
+                    if(!!aThumbBmp)
+                    {
+                        aThumbBmp.Scale(Size(nTargetSizeX, nTargetSizeY), BMP_SCALE_BESTQUALITY);
+                        aThumbBmp.Convert(BMP_CONVERSION_8BIT_COLORS);
+                        bRet = true;
+                    }
+                }
+            }
         }
 	}
 
@@ -545,56 +575,6 @@ sal_Bool SgaObjectSvDraw::CreateThumb( c
 
 // ------------------------------------------------------------------------
 
-sal_Bool SgaObjectSvDraw::DrawCentered( OutputDevice* pOut, const FmFormModel& rModel )
-{
-    const FmFormPage*   pPage = static_cast< const FmFormPage* >( rModel.GetPage( 0 ) );
-    sal_Bool                bRet = sal_False;
-
-    if( pOut && pPage )
-    {
-        const Rectangle aObjRect( pPage->GetAllObjBoundRect() );
-        const Size      aOutSizePix( pOut->GetOutputSizePixel() );
-
-        if( aObjRect.GetWidth() && aObjRect.GetHeight() && aOutSizePix.Width() > 2 && aOutSizePix.Height() > 2 )
-        {
-            FmFormView      aView( const_cast< FmFormModel* >( &rModel ), pOut );
-            MapMode	        aMap( rModel.GetScaleUnit() );
-            Rectangle       aDrawRectPix( Point( 1, 1 ), Size( aOutSizePix.Width() - 2, aOutSizePix.Height() - 2 ) );
-            const double    fFactor  = (double) aObjRect.GetWidth() / aObjRect.GetHeight();
-            Fraction        aFrac( FRound( fFactor < 1. ? aDrawRectPix.GetWidth() * fFactor : aDrawRectPix.GetWidth() ),
-                                   pOut->LogicToPixel( aObjRect.GetSize(), aMap ).Width() );
-
-            aMap.SetScaleX( aFrac );
-            aMap.SetScaleY( aFrac );
-
-            const Size aDrawSize( pOut->PixelToLogic( aDrawRectPix.GetSize(), aMap ) );
-            Point aOrigin( pOut->PixelToLogic( aDrawRectPix.TopLeft(), aMap ) );
-
-            aOrigin.X() += ( ( aDrawSize.Width() - aObjRect.GetWidth() ) >> 1 ) - aObjRect.Left();
-            aOrigin.Y() += ( ( aDrawSize.Height() - aObjRect.GetHeight() ) >> 1 ) - aObjRect.Top();
-            aMap.SetOrigin( aOrigin );
-
-            aView.SetPageVisible( sal_False );
-            aView.SetBordVisible( sal_False );
-            aView.SetGridVisible( sal_False );
-            aView.SetHlplVisible( sal_False );
-            aView.SetGlueVisible( sal_False );
-
-            pOut->Push();
-            pOut->SetMapMode( aMap );
-            aView.ShowSdrPage( const_cast< FmFormPage* >( pPage ));
-            aView.CompleteRedraw( pOut, Rectangle( pOut->PixelToLogic( Point() ), pOut->GetOutputSize() ) );
-            pOut->Pop();
-
-            bRet = sal_True;
-        }
-    }
-
-    return bRet;
-}
-
-// ------------------------------------------------------------------------
-
 void SgaObjectSvDraw::WriteData( SvStream& rOut, const String& rDestDir ) const
 {
 	SgaObject::WriteData( rOut, rDestDir );
@@ -613,3 +593,5 @@ void SgaObjectSvDraw::ReadData( SvStream
 		rIn >> aTmpStr; aTitle = String( aTmpStr.GetBuffer(), RTL_TEXTENCODING_UTF8 );
 	}
 }
+
+// eof

Modified: openoffice/branches/l10n/main/svx/source/gallery2/galtheme.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/gallery2/galtheme.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/gallery2/galtheme.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/gallery2/galtheme.cxx Sun Feb  3 13:23:59 2013
@@ -790,7 +790,7 @@ GalleryThemeEntry* GalleryTheme::CreateT
 
 // -----------------------------------------------------------------------------
 
-sal_Bool GalleryTheme::GetThumb( sal_uIntPtr nPos, Bitmap& rBmp, sal_Bool )
+sal_Bool GalleryTheme::GetThumb( sal_uIntPtr nPos, BitmapEx& rBmp, sal_Bool )
 {
 	SgaObject*	pObj = AcquireObject( nPos );
 	sal_Bool		bRet = sal_False;
@@ -862,9 +862,10 @@ sal_Bool GalleryTheme::GetGraphic( sal_u
 
 				if( pObj )
 				{
-					Bitmap aBmp( pObj->GetThumbBmp() );
-					aBmp.Replace( COL_LIGHTMAGENTA, COL_WHITE );
-					rGraphic = aBmp;
+                    rGraphic = pObj->GetThumbBmp();
+					//Bitmap aBmp( pObj->GetThumbBmp() );
+					//aBmp.Replace( COL_LIGHTMAGENTA, COL_WHITE );
+					//rGraphic = aBmp;
 					ReleaseObject( pObj );
 					bRet = sal_True;
 				}

Modified: openoffice/branches/l10n/main/svx/source/gallery2/galtheme.src
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/gallery2/galtheme.src?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/gallery2/galtheme.src (original)
+++ openoffice/branches/l10n/main/svx/source/gallery2/galtheme.src Sun Feb  3 13:23:59 2013
@@ -123,6 +123,14 @@ String RID_GALLERYSTR_THEME_SURFACES
 
 // -----------------------------------------------------------------------------
 
+String RID_GALLERYSTR_THEME_HTMLBUTTONS
+{
+	// !!! Don't translate, please !!!
+	Text = "private://gallery/hidden/HtmlExportButtons";
+};
+
+// -----------------------------------------------------------------------------
+
 String RID_GALLERYSTR_THEME_POWERPOINT
 {
 	// !!! Don't translate, please !!!
@@ -138,6 +146,38 @@ String RID_GALLERYSTR_THEME_RULERS
 
 // -----------------------------------------------------------------------------
 
+String RID_GALLERYSTR_THEME_COMPUTERS
+{
+       Text [ en-US ] = "Computers";
+};
+
+String RID_GALLERYSTR_THEME_DIAGRAMS
+{
+       Text [ en-US ] = "Diagrams";
+};
+
+String RID_GALLERYSTR_THEME_ENVIRONMENT
+{
+       Text [ en-US ] = "Environment";
+};
+
+String RID_GALLERYSTR_THEME_FINANCE
+{
+       Text [ en-US ] = "Finance";
+};
+
+String RID_GALLERYSTR_THEME_TRANSPORT
+{
+       Text [ en-US ] = "Transport";
+};
+
+String RID_GALLERYSTR_THEME_TXTSHAPES
+{
+       Text [ en-US ] = "Textshapes";
+};
+
+// -----------------------------------------------------------------------------
+
 String RID_GALLERYSTR_THEME_SOUNDS
 {
 	Text [ en-US ] = "Sounds";

Modified: openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofobjlistpainter.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofobjlistpainter.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofobjlistpainter.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofobjlistpainter.cxx Sun Feb  3 13:23:59 2013
@@ -30,9 +30,8 @@
 #include <svx/svdobj.hxx>
 #include <svx/sdr/contact/viewcontact.hxx>
 #include <svx/svdmodel.hxx>
-#include <drawinglayer/processor2d/vclprocessor2d.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
-#include <svx/sdr/contact/objectcontacttools.hxx>
+#include <drawinglayer/processor2d/processor2dtools.hxx>
 #include <svx/unoapi.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
@@ -134,8 +133,9 @@ namespace sdr
 					// if there is something to show, use a vclProcessor to render it
 					if(xPrimitiveSequence.hasElements())
 					{
-						drawinglayer::processor2d::BaseProcessor2D* pProcessor2D = createBaseProcessor2DFromOutputDevice(
-							*pTargetDevice, getViewInformation2D());
+						drawinglayer::processor2d::BaseProcessor2D* pProcessor2D = drawinglayer::processor2d::createProcessor2DFromOutputDevice(
+							*pTargetDevice, 
+                            getViewInformation2D());
 
 						if(pProcessor2D)
 						{

Modified: openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofpageview.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofpageview.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/contact/viewcontactofsdrpage.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/contact/viewcontactofsdrpage.cxx Sun Feb  3 13:23:59 2013
@@ -165,18 +165,23 @@ namespace sdr
             }
             else
             {
-                static vcl::DeleteOnDeinit<drawinglayer::primitive2d::DiscreteShadow>
-                    aDiscreteShadow(new drawinglayer::primitive2d::DiscreteShadow(
-                        BitmapEx(ResId(SIP_SA_PAGESHADOW35X35, *ImpGetResMgr()))));
-                if (aDiscreteShadow.get() != NULL)
+                static vcl::DeleteOnDeinit< drawinglayer::primitive2d::DiscreteShadow > aDiscreteShadow(
+                    new drawinglayer::primitive2d::DiscreteShadow(
+                        BitmapEx(
+                            ResId(
+                                SIP_SA_PAGESHADOW35X35, 
+                                *ImpGetResMgr()))));
+
+                if(aDiscreteShadow.get())
                 {
                     const drawinglayer::primitive2d::Primitive2DReference xReference(
                         new drawinglayer::primitive2d::DiscreteShadowPrimitive2D(
                             aPageMatrix, 
-                                *aDiscreteShadow.get()));
-                    
+                            *aDiscreteShadow.get()));
+
                     return drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
                 }
+
                 return drawinglayer::primitive2d::Primitive2DSequence();
             }
 		}

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayanimatedbitmapex.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayanimatedbitmapex.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayanimatedbitmapex.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayanimatedbitmapex.cxx Sun Feb  3 13:23:59 2013
@@ -36,19 +36,6 @@ namespace sdr
 {
 	namespace overlay
 	{
-		// #i53216# check blink time value range
-		void OverlayAnimatedBitmapEx::impCheckBlinkTimeValueRange()
-		{
-			if(mnBlinkTime < 25)
-			{
-				mnBlinkTime = 25;
-			}
-			else if(mnBlinkTime > 10000)
-			{
-				mnBlinkTime = 10000;
-			}
-		}
-
 		drawinglayer::primitive2d::Primitive2DSequence OverlayAnimatedBitmapEx::createOverlayObjectPrimitive2DSequence()
 		{
             if(mbOverlayState)
@@ -96,7 +83,7 @@ namespace sdr
 			mbAllowsAnimation = true;
 
 			// #i53216# check blink time value range
-			impCheckBlinkTimeValueRange();
+			mnBlinkTime = impCheckBlinkTimeValueRange(mnBlinkTime);
 		}
 
 		OverlayAnimatedBitmapEx::~OverlayAnimatedBitmapEx()
@@ -175,7 +162,7 @@ namespace sdr
 				mnBlinkTime = nNew;
 
 				// #i53216# check blink time value range
-				impCheckBlinkTimeValueRange();
+				mnBlinkTime = impCheckBlinkTimeValueRange(mnBlinkTime);
 
 				// register change (after change)
 				objectChange();

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanager.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanager.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanager.cxx Sun Feb  3 13:23:59 2013
@@ -32,8 +32,7 @@
 #include <vcl/window.hxx>
 #include <svx/sdr/overlay/overlayobject.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
-#include <drawinglayer/processor2d/baseprocessor2d.hxx>
-#include <svx/sdr/contact/objectcontacttools.hxx>
+#include <drawinglayer/processor2d/processor2dtools.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -55,7 +54,7 @@ namespace sdr
 				const bool bIsAntiAliasing(getDrawinglayerOpt().IsAntiAliasing());
 
 				// create processor
-				drawinglayer::processor2d::BaseProcessor2D* pProcessor = ::sdr::contact::createBaseProcessor2DFromOutputDevice(
+				drawinglayer::processor2d::BaseProcessor2D* pProcessor = drawinglayer::processor2d::createProcessor2DFromOutputDevice(
 					rDestinationDevice, 
 					getCurrentViewInformation2D());
 
@@ -157,8 +156,14 @@ namespace sdr
 				if(OUTDEV_WINDOW == getOutputDevice().GetOutDevType())
 				{
 					const Size aOutputSizePixel(getOutputDevice().GetOutputSizePixel());
-					aViewRange = basegfx::B2DRange(0.0, 0.0, aOutputSizePixel.getWidth(), aOutputSizePixel.getHeight());
-			        aViewRange.transform(getOutputDevice().GetInverseViewTransformation());
+
+                    // only set when we *have* a output size, else let aViewRange
+                    // stay on empty
+                    if(aOutputSizePixel.Width() && aOutputSizePixel.Height())
+                    {
+                        aViewRange = basegfx::B2DRange(0.0, 0.0, aOutputSizePixel.getWidth(), aOutputSizePixel.getHeight());
+                        aViewRange.transform(getOutputDevice().GetInverseViewTransformation());
+                    }
 				}
 
                 OverlayManager* pThis = const_cast< OverlayManager* >(this);

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanagerbuffered.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanagerbuffered.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanagerbuffered.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaymanagerbuffered.cxx Sun Feb  3 13:23:59 2013
@@ -19,8 +19,6 @@
  * 
  *************************************************************/
 
-
-
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svx.hxx"
 #include <svx/sdr/overlay/overlaymanagerbuffered.hxx>
@@ -33,6 +31,7 @@
 #include <tools/stream.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <vcl/cursor.hxx>
+#include <vcl/dibtools.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -253,7 +252,7 @@ namespace sdr
                 {
                     const Bitmap aBitmap(maBufferDevice.GetBitmap(aTopLeft, aSize));
                     SvFileStream aNew((const String&)String(ByteString( "c:\\test.bmp" ), RTL_TEXTENCODING_UTF8), STREAM_WRITE|STREAM_TRUNC);
-                    aNew << aBitmap;
+                    WriteDIB(aBitmap, aNew, false, true);
                 }
 #endif
             }

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayobject.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayobject.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayobject.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayobject.cxx Sun Feb  3 13:23:59 2013
@@ -34,7 +34,6 @@
 #include <basegfx/polygon/b2dpolypolygon.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
-#include <svx/sdr/contact/objectcontacttools.hxx>
 #include <drawinglayer/primitive2d/polygonprimitive2d.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
@@ -72,6 +71,20 @@ namespace sdr
             return drawinglayer::primitive2d::Primitive2DSequence();
         }
 
+        sal_uInt32 OverlayObject::impCheckBlinkTimeValueRange(sal_uInt32 nBlinkTime) const
+        {
+            if(nBlinkTime < 25)
+            {
+                nBlinkTime = 25;
+            }
+            else if(nBlinkTime > 10000)
+            {
+                nBlinkTime = 10000;
+            }
+
+            return nBlinkTime;
+        }
+
 		void OverlayObject::allowAntiAliase(bool bNew)
         {
 			if(bNew != (bool)mbAllowsAntiAliase)

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaypolypolygon.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaypolypolygon.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaypolypolygon.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaypolypolygon.cxx Sun Feb  3 13:23:59 2013
@@ -37,7 +37,7 @@ namespace sdr
 {
 	namespace overlay
 	{
-		drawinglayer::primitive2d::Primitive2DSequence OverlayPolyPolygonStriped::createOverlayObjectPrimitive2DSequence()
+		drawinglayer::primitive2d::Primitive2DSequence OverlayPolyPolygonStripedAndFilled::createOverlayObjectPrimitive2DSequence()
 		{
 			drawinglayer::primitive2d::Primitive2DSequence aRetval;
 
@@ -46,43 +46,56 @@ namespace sdr
                 const basegfx::BColor aRGBColorA(getOverlayManager()->getStripeColorA().getBColor());
                 const basegfx::BColor aRGBColorB(getOverlayManager()->getStripeColorB().getBColor());
                 const double fStripeLengthPixel(getOverlayManager()->getStripeLengthPixel());
-
-                const drawinglayer::primitive2d::Primitive2DReference aReference(
+                const drawinglayer::primitive2d::Primitive2DReference aStriped(
                     new drawinglayer::primitive2d::PolyPolygonMarkerPrimitive2D(
-                        getPolyPolygon(),
+                        getLinePolyPolygon(),
                         aRGBColorA,
                         aRGBColorB,
                         fStripeLengthPixel));
 
-                aRetval = drawinglayer::primitive2d::Primitive2DSequence(&aReference, 1);
+                aRetval = drawinglayer::primitive2d::Primitive2DSequence(&aStriped, 1);
+
+                const SvtOptionsDrawinglayer aSvtOptionsDrawinglayer;
+                const basegfx::BColor aHilightColor(aSvtOptionsDrawinglayer.getHilightColor().getBColor());
+                const double fTransparence(aSvtOptionsDrawinglayer.GetTransparentSelectionPercent() * 0.01);
+
+                const drawinglayer::primitive2d::Primitive2DReference aFilled(
+                    new drawinglayer::primitive2d::PolyPolygonSelectionPrimitive2D(
+                        getLinePolyPolygon(),
+                        aHilightColor,
+                        fTransparence,
+                        3.0,
+                        false));
+
+                drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(aRetval, aFilled);
             }
 
             return aRetval;
 		}
 
-		void OverlayPolyPolygonStriped::stripeDefinitionHasChanged()
+		void OverlayPolyPolygonStripedAndFilled::stripeDefinitionHasChanged()
 		{
 			// react on OverlayManager's stripe definition change
 			objectChange();
 		}
 
-		OverlayPolyPolygonStriped::OverlayPolyPolygonStriped(
-			const basegfx::B2DPolyPolygon& rPolyPolygon)
+		OverlayPolyPolygonStripedAndFilled::OverlayPolyPolygonStripedAndFilled(
+			const basegfx::B2DPolyPolygon& rLinePolyPolygon)
 		:	OverlayObject(Color(COL_BLACK)),
-			maPolyPolygon(rPolyPolygon)
+			maLinePolyPolygon(rLinePolyPolygon)
 		{
 		}
 		
-		OverlayPolyPolygonStriped::~OverlayPolyPolygonStriped()
+		OverlayPolyPolygonStripedAndFilled::~OverlayPolyPolygonStripedAndFilled()
 		{
 		}
 
-		void OverlayPolyPolygonStriped::setPolyPolygon(const basegfx::B2DPolyPolygon& rNew)
+		void OverlayPolyPolygonStripedAndFilled::setLinePolyPolygon(const basegfx::B2DPolyPolygon& rNew)
 		{
-			if(rNew != maPolyPolygon)
+			if(rNew != maLinePolyPolygon)
 			{
 				// remember new value
-				maPolyPolygon = rNew;
+				maLinePolyPolygon = rNew;
 
 				// register change (after change)
 				objectChange();

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayprimitive2dsequenceobject.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayprimitive2dsequenceobject.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayprimitive2dsequenceobject.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayprimitive2dsequenceobject.cxx Sun Feb  3 13:23:59 2013
@@ -26,8 +26,6 @@
 
 #include <svx/sdr/overlay/overlayprimitive2dsequenceobject.hxx>
 #include <drawinglayer/geometry/viewinformation2d.hxx>
-#include <drawinglayer/processor2d/vclpixelprocessor2d.hxx>
-#include <svx/sdr/contact/objectcontacttools.hxx>
 #include <svx/sdr/overlay/overlaymanager.hxx>
 
 //////////////////////////////////////////////////////////////////////////////

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayrollingrectangle.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayrollingrectangle.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayrollingrectangle.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlayrollingrectangle.cxx Sun Feb  3 13:23:59 2013
@@ -32,7 +32,7 @@
 #include <svx/sdr/overlay/overlaymanager.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
-#include <drawinglayer/primitive2d/polygonprimitive2d.hxx>
+#include <drawinglayer/primitive2d/polypolygonprimitive2d.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -49,20 +49,30 @@ namespace sdr
                 const basegfx::BColor aRGBColorA(getOverlayManager()->getStripeColorA().getBColor());
                 const basegfx::BColor aRGBColorB(getOverlayManager()->getStripeColorB().getBColor());
                 const double fStripeLengthPixel(getOverlayManager()->getStripeLengthPixel());
-    			const basegfx::B2DRange aRollingRectangle(getBasePosition(), getSecondPosition());
-                
+                const basegfx::B2DRange aRollingRectangle(getBasePosition(), getSecondPosition());
+
                 if(getShowBounds())
                 {
                     // view-independent part, create directly
-    			    const basegfx::B2DPolygon aPolygon(basegfx::tools::createPolygonFromRect(aRollingRectangle));
-                    const drawinglayer::primitive2d::Primitive2DReference aReference(
-                        new drawinglayer::primitive2d::PolygonMarkerPrimitive2D(
-                            aPolygon,
-                            aRGBColorA,
-                            aRGBColorB,
-                            fStripeLengthPixel));
+                    const basegfx::B2DPolygon aPolygon(basegfx::tools::createPolygonFromRect(aRollingRectangle));
 
-                    drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(aRetval, aReference);
+                    aRetval.realloc(2);
+                    aRetval[0] = new drawinglayer::primitive2d::PolyPolygonMarkerPrimitive2D(
+                        basegfx::B2DPolyPolygon(aPolygon),
+                        aRGBColorA,
+                        aRGBColorB,
+                        fStripeLengthPixel);
+
+                    const SvtOptionsDrawinglayer aSvtOptionsDrawinglayer;
+                    const basegfx::BColor aHilightColor(aSvtOptionsDrawinglayer.getHilightColor().getBColor());
+                    const double fTransparence(aSvtOptionsDrawinglayer.GetTransparentSelectionPercent() * 0.01);
+
+                    aRetval[1] = new drawinglayer::primitive2d::PolyPolygonSelectionPrimitive2D(
+                        basegfx::B2DPolyPolygon(aPolygon),
+                        aHilightColor,
+                        fTransparence,
+                        3.0,
+                        false);
                 }
 
                 if(getExtendedLines())

Modified: openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaytools.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaytools.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/svdraw/svdcrtv.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/svdraw/svdcrtv.cxx Sun Feb  3 13:23:59 2013
@@ -80,7 +80,8 @@ ImplConnectMarkerOverlay::ImplConnectMar
 			Size aHalfLogicSize(pTargetOverlay->getOutputDevice().PixelToLogic(Size(4, 4)));
 
 			// object
-			::sdr::overlay::OverlayPolyPolygonStriped* pNew = new ::sdr::overlay::OverlayPolyPolygonStriped(aB2DPolyPolygon);
+			::sdr::overlay::OverlayPolyPolygonStripedAndFilled* pNew = new ::sdr::overlay::OverlayPolyPolygonStripedAndFilled(
+                aB2DPolyPolygon);
 			pTargetOverlay->add(*pNew);
 			maObjects.append(*pNew);
 
@@ -105,7 +106,8 @@ ImplConnectMarkerOverlay::ImplConnectMar
 					basegfx::B2DPolyPolygon aTempPolyPoly;
 					aTempPolyPoly.append(aTempPoly);
 
-					pNew = new ::sdr::overlay::OverlayPolyPolygonStriped(aTempPolyPoly);
+					pNew = new ::sdr::overlay::OverlayPolyPolygonStripedAndFilled(
+                        aTempPolyPoly);
 					pTargetOverlay->add(*pNew);
 					maObjects.append(*pNew);
 				}
@@ -166,7 +168,8 @@ void ImpSdrCreateViewExtraData::CreateAn
 
 			if(rPolyPoly.count())
 			{
-				::sdr::overlay::OverlayPolyPolygonStriped* pNew = new ::sdr::overlay::OverlayPolyPolygonStriped(rPolyPoly);
+				::sdr::overlay::OverlayPolyPolygonStripedAndFilled* pNew = new ::sdr::overlay::OverlayPolyPolygonStripedAndFilled(
+                    rPolyPoly);
 				pOverlayManager->add(*pNew);
 				maObjects.append(*pNew);
 			}

Modified: openoffice/branches/l10n/main/svx/source/svdraw/svddrgmt.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/svdraw/svddrgmt.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/svdraw/svddrgmt.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/svdraw/svddrgmt.cxx Sun Feb  3 13:23:59 2013
@@ -67,6 +67,7 @@
 #include <svx/svdopath.hxx>
 #include <svx/polypolygoneditor.hxx>
 #include <drawinglayer/primitive2d/polypolygonprimitive2d.hxx>
+#include <drawinglayer/primitive2d/polygonprimitive2d.hxx>
 #include <drawinglayer/primitive2d/transformprimitive2d.hxx>
 #include <drawinglayer/primitive2d/markerarrayprimitive2d.hxx>
 #include <svx/sdr/primitive2d/sdrattributecreator.hxx>
@@ -124,10 +125,22 @@ drawinglayer::primitive2d::Primitive2DSe
 			aColB.invert();
 		}
 
-		drawinglayer::primitive2d::Primitive2DReference aPolyPolygonMarkerPrimitive2D(
-			new drawinglayer::primitive2d::PolyPolygonMarkerPrimitive2D(aCopy, aColA, aColB, fStripeLength));
-
-		aRetval = drawinglayer::primitive2d::Primitive2DSequence(&aPolyPolygonMarkerPrimitive2D, 1);
+        aRetval.realloc(2);
+        aRetval[0] = new drawinglayer::primitive2d::PolyPolygonMarkerPrimitive2D(
+            aCopy, 
+            aColA, 
+            aColB, 
+            fStripeLength);
+
+        const basegfx::BColor aHilightColor(aSvtOptionsDrawinglayer.getHilightColor().getBColor());
+        const double fTransparence(aSvtOptionsDrawinglayer.GetTransparentSelectionPercent() * 0.01);
+
+        aRetval[1] = new drawinglayer::primitive2d::PolyPolygonSelectionPrimitive2D(
+            aCopy,
+            aHilightColor,
+            fTransparence,
+            3.0,
+            false);
 	}
 
 	return aRetval;
@@ -964,8 +977,8 @@ drawinglayer::primitive2d::Primitive2DSe
 						}
 
 						drawinglayer::primitive2d::Primitive2DReference aPolyPolygonMarkerPrimitive2D(
-							new drawinglayer::primitive2d::PolyPolygonMarkerPrimitive2D(
-								basegfx::B2DPolyPolygon(aEdgePolygon), aColA, aColB, fStripeLength));
+							new drawinglayer::primitive2d::PolygonMarkerPrimitive2D(
+								aEdgePolygon, aColA, aColB, fStripeLength));
 				        drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(aRetval, aPolyPolygonMarkerPrimitive2D);
 					}
 				}
--- openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofpageview.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/contact/objectcontactofpageview.cxx Sun Feb  3 13:23:59 2013
@@ -35,11 +35,10 @@
 #include <svx/sdr/event/eventhandler.hxx>
 #include <svx/sdrpagewindow.hxx>
 #include <svx/sdrpaintwindow.hxx>
-#include <drawinglayer/processor2d/vclprocessor2d.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <drawinglayer/primitive2d/transformprimitive2d.hxx>
-#include <svx/sdr/contact/objectcontacttools.hxx>
 #include <com/sun/star/rendering/XSpriteCanvas.hpp>
+#include <drawinglayer/processor2d/processor2dtools.hxx>
 #include <svx/unoapi.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
@@ -179,6 +178,7 @@ namespace sdr
 			const double fCurrentTime(getPrimitiveAnimator().GetTime());
 			OutputDevice& rTargetOutDev = GetPageWindow().GetPaintWindow().GetTargetOutputDevice();
             basegfx::B2DRange aViewRange;
+            basegfx::B2DHomMatrix aViewTransformation;
 
 			// create ViewRange
             if(isOutputToRecordingMetaFile())
@@ -228,12 +228,16 @@ namespace sdr
 
 				// transform to world coordinates
                 aViewRange.transform(rTargetOutDev.GetInverseViewTransformation());
+
+                // for metafile, leave ViewTransformation empty, but for pixel renderer
+                // get it from OutputDevice
+                aViewTransformation = rTargetOutDev.GetViewTransformation();
 			}
 
 			// update local ViewInformation2D
 			const drawinglayer::geometry::ViewInformation2D aNewViewInformation2D(
 				basegfx::B2DHomMatrix(), 
-				rTargetOutDev.GetViewTransformation(), 
+				aViewTransformation, 
 				aViewRange, 
 				GetXDrawPageForSdrPage(GetSdrPage()),
 				fCurrentTime, 
@@ -246,7 +250,7 @@ namespace sdr
 
 			// if there is something to show, use a primitive processor to render it. There
 			// is a choice between VCL and Canvas processors currently. The decision is made in
 			// createBaseProcessor2DFromOutputDevice and takes into accout things like the
 			// Target is a MetaFile, a VDev or something else. The Canvas renderer is triggered
 			// currently using the shown boolean. Canvas is not yet the default.
 			if(xPrimitiveSequence.hasElements())
@@ -256,8 +260,9 @@ namespace sdr
 				pOutDev->SetLayoutMode(0); // reset, default is no BiDi/RTL
 
 				// create renderer
-                drawinglayer::processor2d::BaseProcessor2D* pProcessor2D = createBaseProcessor2DFromOutputDevice(
-                    rTargetOutDev, getViewInformation2D());
+                drawinglayer::processor2d::BaseProcessor2D* pProcessor2D = drawinglayer::processor2d::createProcessor2DFromOutputDevice(
+                    rTargetOutDev, 
+                    getViewInformation2D());
 
 				if(pProcessor2D)
 				{
@@ -246,7 +250,7 @@ namespace sdr
 			// if there is something to show, use a primitive processor to render it. There
 			// is a choice between VCL and Canvas processors currently. The decision is made in
-			// createBaseProcessor2DFromOutputDevice and takes into accout things like the
+			// createProcessor2DFromOutputDevice and takes into accout things like the
 			// Target is a MetaFile, a VDev or something else. The Canvas renderer is triggered
 			// currently using the shown boolean. Canvas is not yet the default.

Modified: openoffice/branches/l10n/main/svx/source/sdr/contact/viewcontactofsdrpage.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/sdr/contact/viewcontactofsdrpage.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================
--- openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaytools.cxx (original)
+++ openoffice/branches/l10n/main/svx/source/sdr/overlay/overlaytools.cxx Sun Feb  3 13:23:59 2013
@@ -34,6 +34,8 @@
 #include <drawinglayer/primitive2d/polypolygonprimitive2d.hxx>
 #include <drawinglayer/geometry/viewinformation2d.hxx>
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
+#include <drawinglayer/primitive2d/unifiedtransparenceprimitive2d.hxx>
+#include <vcl/svapp.hxx>
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -67,8 +69,8 @@ namespace drawinglayer
                 // and unrotated, more like a marker
                 const double fLeft(((0.0 - getCenterX()) * getDiscreteUnit()) + getBasePosition().getX());
                 const double fTop(((0.0 - getCenterY()) * getDiscreteUnit()) + getBasePosition().getY());
-                const double fRight((((aBitmapSize.getWidth() - 1.0) - getCenterX()) * getDiscreteUnit()) + getBasePosition().getX());
-                const double fBottom((((aBitmapSize.getHeight() - 1.0) - getCenterY()) * getDiscreteUnit()) + getBasePosition().getY());
+                const double fRight(((aBitmapSize.getWidth() - getCenterX()) * getDiscreteUnit()) + getBasePosition().getX());
+                const double fBottom(((aBitmapSize.getHeight() - getCenterY()) * getDiscreteUnit()) + getBasePosition().getY());
 
                 // create a BitmapPrimitive2D using those positions
 				basegfx::B2DHomMatrix aTransform;
@@ -184,82 +186,122 @@ namespace drawinglayer
 {
 	namespace primitive2d
 	{
-        OverlayHatchRectanglePrimitive::OverlayHatchRectanglePrimitive(
+        OverlayRectanglePrimitive::OverlayRectanglePrimitive(
             const basegfx::B2DRange& rObjectRange,
-			double fDiscreteHatchDistance,
-			double fHatchRotation,
-			const basegfx::BColor& rHatchColor,
+			const basegfx::BColor& rColor,
+            double fTransparence,
             double fDiscreteGrow,
             double fDiscreteShrink,
             double fRotation)
         :   DiscreteMetricDependentPrimitive2D(),
             maObjectRange(rObjectRange),
-			mfDiscreteHatchDistance(fDiscreteHatchDistance),
-			mfHatchRotation(fHatchRotation),
-			maHatchColor(rHatchColor),
+			maColor(rColor),
+            mfTransparence(fTransparence),
             mfDiscreteGrow(fDiscreteGrow),
             mfDiscreteShrink(fDiscreteShrink),
             mfRotation(fRotation)
         {}
 
-		Primitive2DSequence OverlayHatchRectanglePrimitive::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+		Primitive2DSequence OverlayRectanglePrimitive::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
 		{
             Primitive2DSequence aRetval;
-			
-            if(basegfx::fTools::more(getDiscreteUnit(), 0.0))
+            basegfx::B2DRange aInnerRange(getObjectRange());
+
+            if(!aInnerRange.isEmpty() && basegfx::fTools::more(getDiscreteUnit(), 0.0) && getTransparence() <= 1.0)
             {
-			    basegfx::B2DRange aInnerRange(getObjectRange());
-			    basegfx::B2DRange aOuterRange(getObjectRange());
-			    basegfx::B2DPolyPolygon aHatchPolyPolygon;
-
-			    aOuterRange.grow(getDiscreteUnit() * getDiscreteGrow());
-			    aInnerRange.grow(getDiscreteUnit() * -getDiscreteShrink());
-
-			    aHatchPolyPolygon.append(basegfx::tools::createPolygonFromRect(aOuterRange));
-
-				if(!aInnerRange.isEmpty())
-				{
-				    aHatchPolyPolygon.append(basegfx::tools::createPolygonFromRect(aInnerRange));
-				}
-                
-			    if(!basegfx::fTools::equalZero(getRotation()))
-			    {
+                basegfx::B2DRange aInnerRange(getObjectRange());
+                basegfx::B2DRange aOuterRange(getObjectRange());
+
+                // grow/shrink inner/outer polygons
+                aOuterRange.grow(getDiscreteUnit() * getDiscreteGrow());
+                aInnerRange.grow(getDiscreteUnit() * -getDiscreteShrink());
+
+                // convert to polygons
+                const double fFullGrow(getDiscreteGrow() + getDiscreteShrink());
+                const double fRelativeRadiusX(fFullGrow / aOuterRange.getWidth());
+                const double fRelativeRadiusY(fFullGrow / aOuterRange.getHeight());
+                basegfx::B2DPolygon aOuterPolygon(
+                    basegfx::tools::createPolygonFromRect(
+                        aOuterRange,
+                        fRelativeRadiusX,
+                        fRelativeRadiusY));
+                basegfx::B2DPolygon aInnerPolygon(
+                    basegfx::tools::createPolygonFromRect(
+                        aInnerRange));
+
+                // apply evtl. existing rotation
+                if(!basegfx::fTools::equalZero(getRotation()))
+                {
                     const basegfx::B2DHomMatrix aTransform(basegfx::tools::createRotateAroundPoint(
                         getObjectRange().getMinX(), getObjectRange().getMinY(), getRotation()));
 
-                    aHatchPolyPolygon.transform(aTransform);
-			    }
-
-                const basegfx::BColor aEmptyColor(0.0, 0.0, 0.0);
-				const drawinglayer::attribute::FillHatchAttribute aFillHatchAttribute(
-					drawinglayer::attribute::HATCHSTYLE_SINGLE,
-					getDiscreteHatchDistance() * getDiscreteUnit(),
-					getHatchRotation() - getRotation(),
-					getHatchColor(),
-                    3, // same default as VCL, a minimum of three discrete units (pixels) offset
-					false);
-                const Primitive2DReference aPrimitive(
-                    new PolyPolygonHatchPrimitive2D(
-                        aHatchPolyPolygon,
-                        aEmptyColor,
-                        aFillHatchAttribute));
-
-                aRetval = Primitive2DSequence(&aPrimitive, 1);
+                    aOuterPolygon.transform(aTransform);
+                    aInnerPolygon.transform(aTransform);
+                }
+
+                // create filled primitive
+                basegfx::B2DPolyPolygon aPolyPolygon;
+
+                aPolyPolygon.append(aOuterPolygon);
+                aPolyPolygon.append(aInnerPolygon);
+
+                if(Application::GetSettings().GetStyleSettings().GetHighContrastMode())
+                {
+                    // for high contrast, use hatch
+                    const basegfx::BColor aHighContrastLineColor(Application::GetSettings().GetStyleSettings().GetFontColor().getBColor());
+                    const basegfx::BColor aEmptyColor(0.0, 0.0, 0.0);
+                    const double fHatchRotation(45 * F_PI180);
+                    const double fDiscreteHatchDistance(3.0);
+                    const drawinglayer::attribute::FillHatchAttribute aFillHatchAttribute(
+                        drawinglayer::attribute::HATCHSTYLE_SINGLE,
+                        fDiscreteHatchDistance * getDiscreteUnit(),
+                        fHatchRotation - getRotation(),
+                        aHighContrastLineColor,
+                        3, // same default as VCL, a minimum of three discrete units (pixels) offset
+                        false);
+                    const Primitive2DReference aHatch(
+                        new PolyPolygonHatchPrimitive2D(
+                            aPolyPolygon,
+                            aEmptyColor,
+                            aFillHatchAttribute));
+
+                    aRetval = Primitive2DSequence(&aHatch, 1);
+                }
+                else
+                {
+                    // create fill primitive
+                    const Primitive2DReference aFill(
+                        new PolyPolygonColorPrimitive2D(
+                            aPolyPolygon,
+                            getColor()));
+
+                    aRetval = Primitive2DSequence(&aFill, 1);
+
+                    // embed filled to transparency (if used)
+                    if(getTransparence() > 0.0)
+                    {
+                        const Primitive2DReference aFillTransparent(
+                            new UnifiedTransparencePrimitive2D(
+                                aRetval, 
+                                getTransparence()));
+
+                        aRetval = Primitive2DSequence(&aFillTransparent, 1);
+                    }
+                }
             }
 
             return aRetval;
-		}
+        }
 
-		bool OverlayHatchRectanglePrimitive::operator==( const BasePrimitive2D& rPrimitive ) const
+		bool OverlayRectanglePrimitive::operator==( const BasePrimitive2D& rPrimitive ) const
 		{
 			if(DiscreteMetricDependentPrimitive2D::operator==(rPrimitive))
 			{
-				const OverlayHatchRectanglePrimitive& rCompare = static_cast< const OverlayHatchRectanglePrimitive& >(rPrimitive);
+				const OverlayRectanglePrimitive& rCompare = static_cast< const OverlayRectanglePrimitive& >(rPrimitive);
 
 				return (getObjectRange() == rCompare.getObjectRange()
-					&& getDiscreteHatchDistance() == rCompare.getDiscreteHatchDistance()
-					&& getHatchRotation() == rCompare.getHatchRotation()
-					&& getHatchColor() == rCompare.getHatchColor()
+					&& getColor() == rCompare.getColor()
+                    && getTransparence() == rCompare.getTransparence()
 					&& getDiscreteGrow() == rCompare.getDiscreteGrow()
 					&& getDiscreteShrink() == rCompare.getDiscreteShrink()
 					&& getRotation() == rCompare.getRotation());
@@ -268,7 +310,7 @@ namespace drawinglayer
 			return false;
 		}
 
-		ImplPrimitrive2DIDBlock(OverlayHatchRectanglePrimitive, PRIMITIVE2D_ID_OVERLAYHATCHRECTANGLEPRIMITIVE)
+		ImplPrimitrive2DIDBlock(OverlayRectanglePrimitive, PRIMITIVE2D_ID_OVERLAYRECTANGLEPRIMITIVE)
 
 	} // end of namespace primitive2d
 } // end of namespace drawinglayer

Modified: openoffice/branches/l10n/main/svx/source/svdraw/svdcrtv.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/l10n/main/svx/source/svdraw/svdcrtv.cxx?rev=1441909&r1=1441908&r2=1441909&view=diff
==============================================================================